### Installation

    pip install easyi3status

### Configuration:

    # edit configuration file with your credentials
    ~/.easyi3status/config.cfg

### i3 Configuration

    # place this in your i3 config
    bar {
    	status_command easyi3status
    }

And you're ready to go